
Reference guides
=================


For a detailed explanation of the HSOM class, including diagnosing the training process using topographic and quantization errors refer to the following notebook.

.. toctree::
   :maxdepth: 1

   The HSOM class <../tutorials/thesomclass>

To explore the visualization functions available in the package, refer to the following notebook.

.. toctree::
   :maxdepth: 1

   Plotting functions <../tutorials/vizfunctions>